[lgtk-devel] patch? : 'callback' package not needed in cmu19a

Sean Champ gimbal at sdf.lonestar.org
Sun Aug 1 04:09:56 UTC 2004


Hello,

(short in words, here -- not meaning excessive terseness, just
momentarily tired of adding fluff around plain statements, and of
guessing about what should be added, first or later. so, to it...)


cmucl 19a does include the callback routines


cmucl 19a does not have a "callback" package (it puts the callback
routines in ALIEN)

cmucl 19a uses "def-callback" instead of "defcallback"



the following patch is probably not the best way for patching lgtk's
port.lisp accordingly, but it works -- tried and tested with the lgtk
hello-world one and two.



hasta

--
sean



Index: src/port.lisp
===================================================================
RCS file: /project/lgtk/cvsroot/lgtk/src/port.lisp,v
retrieving revision 1.4
diff -p -u -r1.4 port.lisp
--- src/port.lisp	11 Dec 2003 10:48:00 -0000	1.4
+++ src/port.lisp	30 Jul 2004 16:00:44 -0000
@@ -11,7 +11,7 @@
 	   #:weak-pointer-value #:*weak-pointer-type* #:run-after-gc
 	   #:def-alien-routine #:port-alien-type #:def-c-callable #:c-fun-ptr
 	   #:swap-unix-sigint-handler #:voidptr #:peek #:poke)
   #+cmu (:use common-lisp ext system alien c-call callback)
   #+sbcl (:use common-lisp sb-ext sb-sys sb-alien callback)
   (:shadow def-alien-routine finalize make-weak-pointer weak-pointer-value))
 
@@ -129,7 +129,7 @@ from the the C-CALL (CMUCL) or SB-ALIEN 
   "Defines a callback using the `port' C type specifiers. Uses
 PORT-ALIEN-TYPE to convert the syntax to the implementation-dependant
 alien type specifiers."
-  `(defcallback ,name 
+  `(#-cmu19 defcallback #+cmu19 def-callback ,name 
     ,(list* (port-alien-type return-type)
 	    (mapcar (lambda (arg-spec)
 		      (destructuring-bind (name type) arg-spec
@@ -11,7 +11,7 @@
 	   #:def-alien-routine #:port-alien-type #:def-c-callable #:c-fun-ptr
 	   #:swap-unix-sigint-handler #:voidptr #:peek #:poke)
-  #+cmu (:use common-lisp ext system alien c-call callback)
+  #+cmu (:use common-lisp ext system alien c-call #-cmu19 callback)
   #+sbcl (:use common-lisp sb-ext sb-sys sb-alien callback)
   (:shadow def-alien-routine finalize make-weak-pointer weak-pointer-value))




More information about the lgtk-devel mailing list